aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--components/canvas/Cargo.toml4
-rw-r--r--components/canvas/canvas_paint_task.rs8
-rw-r--r--components/canvas/lib.rs2
-rw-r--r--components/canvas/webgl_paint_task.rs2
-rw-r--r--components/canvas_traits/Cargo.toml4
-rw-r--r--components/canvas_traits/lib.rs10
-rw-r--r--components/compositing/Cargo.toml4
-rw-r--r--components/compositing/compositor.rs8
-rw-r--r--components/compositing/compositor_layer.rs10
-rw-r--r--components/compositing/compositor_task.rs4
-rw-r--r--components/compositing/constellation.rs8
-rw-r--r--components/compositing/headless.rs4
-rw-r--r--components/compositing/lib.rs2
-rw-r--r--components/compositing/pipeline.rs4
-rw-r--r--components/compositing/windowing.rs6
-rw-r--r--components/gfx/Cargo.toml4
-rw-r--r--components/gfx/buffer_map.rs2
-rw-r--r--components/gfx/display_list/mod.rs6
-rw-r--r--components/gfx/display_list/optimizer.rs2
-rw-r--r--components/gfx/font.rs2
-rw-r--r--components/gfx/lib.rs2
-rw-r--r--components/gfx/paint_context.rs10
-rw-r--r--components/gfx/paint_task.rs8
-rw-r--r--components/gfx/text/glyph.rs2
-rw-r--r--components/gfx/text/shaping/harfbuzz.rs2
-rw-r--r--components/layout/Cargo.toml4
-rw-r--r--components/layout/block.rs2
-rw-r--r--components/layout/context.rs2
-rw-r--r--components/layout/display_list_builder.rs4
-rw-r--r--components/layout/flow.rs2
-rw-r--r--components/layout/fragment.rs2
-rw-r--r--components/layout/inline.rs2
-rw-r--r--components/layout/layout_task.rs10
-rw-r--r--components/layout/lib.rs2
-rw-r--r--components/layout/list_item.rs2
-rw-r--r--components/layout/model.rs2
-rw-r--r--components/layout/multicol.rs2
-rw-r--r--components/layout/sequential.rs2
-rw-r--r--components/layout/table.rs2
-rw-r--r--components/layout/table_caption.rs2
-rw-r--r--components/layout/table_cell.rs2
-rw-r--r--components/layout/table_colgroup.rs2
-rw-r--r--components/layout/table_row.rs2
-rw-r--r--components/layout/table_rowgroup.rs2
-rw-r--r--components/layout/table_wrapper.rs2
-rw-r--r--components/layout_traits/Cargo.toml4
-rw-r--r--components/layout_traits/lib.rs4
-rw-r--r--components/msg/Cargo.toml4
-rw-r--r--components/msg/compositor_msg.rs4
-rw-r--r--components/msg/constellation_msg.rs6
-rw-r--r--components/msg/lib.rs2
-rw-r--r--components/net/Cargo.toml4
-rw-r--r--components/net/lib.rs2
-rw-r--r--components/net_traits/Cargo.toml5
-rw-r--r--components/net_traits/lib.rs2
-rw-r--r--components/script/Cargo.toml4
-rw-r--r--components/script/dom/bindings/trace.rs6
-rw-r--r--components/script/dom/canvaspattern.rs2
-rw-r--r--components/script/dom/canvasrenderingcontext2d.rs8
-rw-r--r--components/script/dom/document.rs2
-rw-r--r--components/script/dom/htmlcanvaselement.rs2
-rw-r--r--components/script/dom/imagedata.rs2
-rw-r--r--components/script/dom/node.rs2
-rw-r--r--components/script/dom/webglrenderingcontext.rs2
-rw-r--r--components/script/dom/window.rs2
-rw-r--r--components/script/layout_interface.rs4
-rw-r--r--components/script/lib.rs2
-rw-r--r--components/script/script_task.rs4
-rw-r--r--components/script_traits/Cargo.toml4
-rw-r--r--components/script_traits/lib.rs6
-rw-r--r--components/servo/Cargo.lock70
-rw-r--r--components/style/Cargo.toml3
-rw-r--r--components/style/lib.rs2
-rw-r--r--components/style/media_queries.rs2
-rw-r--r--components/style/properties.mako.rs8
-rw-r--r--components/style/values.rs4
-rw-r--r--components/style/viewport.rs4
-rw-r--r--components/util/Cargo.toml4
-rw-r--r--components/util/bezier.rs2
-rw-r--r--components/util/geometry.rs12
-rw-r--r--components/util/lib.rs2
-rw-r--r--components/util/logical_geometry.rs4
-rw-r--r--components/util/mem.rs2
-rw-r--r--components/util/opts.rs4
-rw-r--r--ports/cef/Cargo.lock68
-rw-r--r--ports/cef/Cargo.toml4
-rw-r--r--ports/cef/browser_host.rs4
-rw-r--r--ports/cef/lib.rs2
-rw-r--r--ports/cef/window.rs4
-rw-r--r--ports/glutin/Cargo.toml4
-rw-r--r--ports/glutin/lib.rs4
-rw-r--r--ports/glutin/window.rs6
-rw-r--r--ports/gonk/Cargo.lock66
-rw-r--r--ports/gonk/Cargo.toml4
-rw-r--r--ports/gonk/src/input.rs2
-rw-r--r--ports/gonk/src/main.rs2
-rw-r--r--ports/gonk/src/window.rs4
-rw-r--r--tests/unit/style/Cargo.toml4
-rw-r--r--tests/unit/style/lib.rs2
-rw-r--r--tests/unit/style/media_queries.rs2
-rw-r--r--tests/unit/style/viewport.rs4
-rw-r--r--tests/unit/util/Cargo.toml4
-rw-r--r--tests/unit/util/lib.rs2
-rw-r--r--tests/unit/util/logical_geometry.rs2
104 files changed, 272 insertions, 306 deletions
diff --git a/components/canvas/Cargo.toml b/components/canvas/Cargo.toml
index 2cf2771cb6e..6300014b45c 100644
--- a/components/canvas/Cargo.toml
+++ b/components/canvas/Cargo.toml
@@ -10,9 +10,6 @@ path = "lib.rs"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -35,3 +32,4 @@ log = "*"
cssparser = "0.3.1"
num = "0.1.24"
gleam = "0.1"
+euclid = "0.1"
diff --git a/components/canvas/canvas_paint_task.rs b/components/canvas/canvas_paint_task.rs
index c09dc021579..f6f4d024f9a 100644
--- a/components/canvas/canvas_paint_task.rs
+++ b/components/canvas/canvas_paint_task.rs
@@ -7,10 +7,10 @@ use azure::azure_hl::{DrawTarget, SurfaceFormat, BackendType, StrokeOptions, Dra
use azure::azure_hl::{ColorPattern, PathBuilder, DrawSurfaceOptions, Filter};
use azure::azure_hl::{JoinStyle, CapStyle, CompositionOp, AntialiasMode};
use canvas_traits::*;
-use geom::matrix2d::Matrix2D;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
+use euclid::matrix2d::Matrix2D;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
use layers::platform::surface::NativeSurface;
use gfx_traits::color;
use num::ToPrimitive;
diff --git a/components/canvas/lib.rs b/components/canvas/lib.rs
index 16ced51b402..4ef4afe390a 100644
--- a/components/canvas/lib.rs
+++ b/components/canvas/lib.rs
@@ -9,7 +9,7 @@ extern crate core;
extern crate canvas_traits;
extern crate azure;
extern crate cssparser;
-extern crate geom;
+extern crate euclid;
extern crate gfx_traits;
extern crate util;
extern crate gleam;
diff --git a/components/canvas/webgl_paint_task.rs b/components/canvas/webgl_paint_task.rs
index 8f8b82c908b..24258954c1e 100644
--- a/components/canvas/webgl_paint_task.rs
+++ b/components/canvas/webgl_paint_task.rs
@@ -3,7 +3,7 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
use canvas_traits::{CanvasMsg, CanvasWebGLMsg, CanvasCommonMsg};
-use geom::size::Size2D;
+use euclid::size::Size2D;
use core::nonzero::NonZero;
use gleam::gl;
use gleam::gl::types::{GLsizei};
diff --git a/components/canvas_traits/Cargo.toml b/components/canvas_traits/Cargo.toml
index 5110ae2e0ef..f2594ca4701 100644
--- a/components/canvas_traits/Cargo.toml
+++ b/components/canvas_traits/Cargo.toml
@@ -10,9 +10,6 @@ path = "lib.rs"
[dependencies.gfx_traits]
path = "../gfx_traits"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
@@ -24,3 +21,4 @@ git = "https://github.com/ecoal95/rust-offscreen-rendering-context"
[dependencies]
cssparser = "0.3.1"
+euclid = "0.1"
diff --git a/components/canvas_traits/lib.rs b/components/canvas_traits/lib.rs
index 3c556b65782..91f3278b4c0 100644
--- a/components/canvas_traits/lib.rs
+++ b/components/canvas_traits/lib.rs
@@ -7,7 +7,7 @@
#![feature(core)]
extern crate core;
extern crate azure;
-extern crate geom;
+extern crate euclid;
extern crate cssparser;
extern crate gfx_traits;
extern crate layers;
@@ -19,10 +19,10 @@ use azure::azure_hl::{GradientStop, LinearGradientPattern, RadialGradientPattern
use azure::azure_hl::{JoinStyle, CapStyle, CompositionOp};
use azure::azure_hl::{SurfacePattern, SurfaceFormat};
use cssparser::RGBA;
-use geom::matrix2d::Matrix2D;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
+use euclid::matrix2d::Matrix2D;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
use gfx_traits::color;
use std::sync::mpsc::{Sender};
use layers::platform::surface::NativeSurface;
diff --git a/components/compositing/Cargo.toml b/components/compositing/Cargo.toml
index 67e5229009e..f543f6c0780 100644
--- a/components/compositing/Cargo.toml
+++ b/components/compositing/Cargo.toml
@@ -43,9 +43,6 @@ path = "../devtools_traits"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -62,6 +59,7 @@ url = "0.2.35"
time = "0.1.17"
libc = "*"
gleam = "0.1"
+euclid = "0.1"
[target.x86_64-apple-darwin.dependencies]
core-graphics = "*"
diff --git a/components/compositing/compositor.rs b/components/compositing/compositor.rs
index 0e668f2717c..8a4d1191b7f 100644
--- a/components/compositing/compositor.rs
+++ b/components/compositing/compositor.rs
@@ -11,10 +11,10 @@ use scrolling::ScrollingTimerProxy;
use windowing;
use windowing::{MouseWindowEvent, WindowEvent, WindowMethods, WindowNavigateMsg};
-use geom::point::{Point2D, TypedPoint2D};
-use geom::rect::{Rect, TypedRect};
-use geom::scale_factor::ScaleFactor;
-use geom::size::{Size2D, TypedSize2D};
+use euclid::point::{Point2D, TypedPoint2D};
+use euclid::rect::{Rect, TypedRect};
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
use gfx_traits::color;
use gfx::paint_task::Msg as PaintMsg;
use gfx::paint_task::PaintRequest;
diff --git a/components/compositing/compositor_layer.rs b/components/compositing/compositor_layer.rs
index 133c45e9bcb..6a34fc785ce 100644
--- a/components/compositing/compositor_layer.rs
+++ b/components/compositing/compositor_layer.rs
@@ -6,11 +6,11 @@ use compositor::IOCompositor;
use windowing::{MouseWindowEvent, WindowMethods};
use azure::azure_hl;
-use geom::length::Length;
-use geom::matrix::Matrix4;
-use geom::point::{Point2D, TypedPoint2D};
-use geom::size::TypedSize2D;
-use geom::rect::Rect;
+use euclid::length::Length;
+use euclid::matrix::Matrix4;
+use euclid::point::{Point2D, TypedPoint2D};
+use euclid::size::TypedSize2D;
+use euclid::rect::Rect;
use gfx::paint_task::Msg as PaintMsg;
use layers::color::Color;
use layers::geometry::LayerPixel;
diff --git a/components/compositing/compositor_task.rs b/components/compositing/compositor_task.rs
index 9e7b172cc80..111fa9dd2a6 100644
--- a/components/compositing/compositor_task.rs
+++ b/components/compositing/compositor_task.rs
@@ -11,8 +11,8 @@ use compositor;
use headless;
use windowing::{WindowEvent, WindowMethods};
-use geom::point::Point2D;
-use geom::rect::Rect;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
use layers::platform::surface::{NativeCompositingGraphicsContext, NativeGraphicsMetadata};
use layers::layers::LayerBufferSet;
use msg::compositor_msg::{Epoch, LayerId, LayerProperties, FrameTreeId};
diff --git a/components/compositing/constellation.rs b/components/compositing/constellation.rs
index 13dbb11037f..2bbe8e3ef05 100644
--- a/components/compositing/constellation.rs
+++ b/components/compositing/constellation.rs
@@ -14,10 +14,10 @@ use pipeline::{Pipeline, CompositionPipeline};
use compositor_task::CompositorProxy;
use compositor_task::Msg as CompositorMsg;
use devtools_traits::{DevtoolsControlChan, DevtoolsControlMsg};
-use geom::point::Point2D;
-use geom::rect::{Rect, TypedRect};
-use geom::size::Size2D;
-use geom::scale_factor::ScaleFactor;
+use euclid::point::Point2D;
+use euclid::rect::{Rect, TypedRect};
+use euclid::size::Size2D;
+use euclid::scale_factor::ScaleFactor;
use gfx::font_cache_task::FontCacheTask;
use layout_traits::{LayoutControlChan, LayoutControlMsg, LayoutTaskFactory};
use libc;
diff --git a/components/compositing/headless.rs b/components/compositing/headless.rs
index e18e1275122..c8a3419454f 100644
--- a/components/compositing/headless.rs
+++ b/components/compositing/headless.rs
@@ -5,8 +5,8 @@
use compositor_task::{CompositorEventListener, CompositorReceiver, Msg};
use windowing::WindowEvent;
-use geom::scale_factor::ScaleFactor;
-use geom::size::Size2D;
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::Size2D;
use msg::constellation_msg::Msg as ConstellationMsg;
use msg::constellation_msg::{ConstellationChan, WindowSizeData};
use profile_traits::mem;
diff --git a/components/compositing/lib.rs b/components/compositing/lib.rs
index cc68de34461..fbb8070892c 100644
--- a/components/compositing/lib.rs
+++ b/components/compositing/lib.rs
@@ -11,7 +11,7 @@ extern crate log;
extern crate azure;
extern crate devtools_traits;
-extern crate geom;
+extern crate euclid;
extern crate gfx;
extern crate layers;
extern crate layout_traits;
diff --git a/components/compositing/pipeline.rs b/components/compositing/pipeline.rs
index c9cfa6ee37d..4305e686951 100644
--- a/components/compositing/pipeline.rs
+++ b/components/compositing/pipeline.rs
@@ -8,8 +8,8 @@ use script_traits::{ScriptControlChan, ScriptTaskFactory};
use script_traits::{NewLayoutInfo, ConstellationControlMsg};
use devtools_traits::DevtoolsControlChan;
-use geom::rect::{TypedRect};
-use geom::scale_factor::ScaleFactor;
+use euclid::rect::{TypedRect};
+use euclid::scale_factor::ScaleFactor;
use gfx::paint_task::Msg as PaintMsg;
use gfx::paint_task::{PaintChan, PaintTask};
use gfx::font_cache_task::FontCacheTask;
diff --git a/components/compositing/windowing.rs b/components/compositing/windowing.rs
index 17ce9f43434..03aafb887b4 100644
--- a/components/compositing/windowing.rs
+++ b/components/compositing/windowing.rs
@@ -6,9 +6,9 @@
use compositor_task::{CompositorProxy, CompositorReceiver};
-use geom::point::TypedPoint2D;
-use geom::scale_factor::ScaleFactor;
-use geom::size::TypedSize2D;
+use euclid::point::TypedPoint2D;
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::TypedSize2D;
use layers::geometry::DevicePixel;
use layers::platform::surface::NativeGraphicsMetadata;
use msg::constellation_msg::{Key, KeyState, KeyModifiers};
diff --git a/components/gfx/Cargo.toml b/components/gfx/Cargo.toml
index 5b5bc001086..5e8cc732564 100644
--- a/components/gfx/Cargo.toml
+++ b/components/gfx/Cargo.toml
@@ -35,9 +35,6 @@ path = "../style"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -65,6 +62,7 @@ rand = "*"
harfbuzz = "0.1"
smallvec = "0.1"
string_cache = "0.1"
+euclid = "0.1"
[target.x86_64-apple-darwin.dependencies]
core-foundation = "*"
diff --git a/components/gfx/buffer_map.rs b/components/gfx/buffer_map.rs
index a3d210627d1..353e2969be6 100644
--- a/components/gfx/buffer_map.rs
+++ b/components/gfx/buffer_map.rs
@@ -4,7 +4,7 @@
use std::collections::HashMap;
use std::collections::hash_map::Entry::{Occupied, Vacant};
-use geom::size::Size2D;
+use euclid::size::Size2D;
use layers::platform::surface::NativePaintingGraphicsContext;
use layers::layers::LayerBuffer;
use std::hash::{Hash, Hasher};
diff --git a/components/gfx/display_list/mod.rs b/components/gfx/display_list/mod.rs
index bf2c839bc7e..22ca879b417 100644
--- a/components/gfx/display_list/mod.rs
+++ b/components/gfx/display_list/mod.rs
@@ -27,9 +27,9 @@ use azure::azure::AzFloat;
use azure::azure_hl::Color;
use std::collections::linked_list::{self, LinkedList};
-use geom::{Point2D, Rect, SideOffsets2D, Size2D, Matrix2D, Matrix4};
-use geom::approxeq::ApproxEq;
-use geom::num::Zero;
+use euclid::{Point2D, Rect, SideOffsets2D, Size2D, Matrix2D, Matrix4};
+use euclid::approxeq::ApproxEq;
+use euclid::num::Zero;
use libc::uintptr_t;
use paint_task::PaintLayer;
use msg::compositor_msg::LayerId;
diff --git a/components/gfx/display_list/optimizer.rs b/components/gfx/display_list/optimizer.rs
index 07d048c8c9c..d7a5297dd1f 100644
--- a/components/gfx/display_list/optimizer.rs
+++ b/components/gfx/display_list/optimizer.rs
@@ -7,7 +7,7 @@
use display_list::{DisplayItem, DisplayList, StackingContext};
use std::collections::linked_list::LinkedList;
-use geom::rect::Rect;
+use euclid::rect::Rect;
use util::geometry::{self, Au};
use std::sync::Arc;
diff --git a/components/gfx/font.rs b/components/gfx/font.rs
index d06540a9657..824523be4bd 100644
--- a/components/gfx/font.rs
+++ b/components/gfx/font.rs
@@ -2,7 +2,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use smallvec::SmallVec8;
use std::borrow::ToOwned;
use std::mem;
diff --git a/components/gfx/lib.rs b/components/gfx/lib.rs
index 3117c8f7a6d..4acd4ef0aa7 100644
--- a/components/gfx/lib.rs
+++ b/components/gfx/lib.rs
@@ -20,7 +20,7 @@ extern crate alloc;
extern crate azure;
#[macro_use] extern crate bitflags;
extern crate fnv;
-extern crate geom;
+extern crate euclid;
extern crate layers;
extern crate libc;
extern crate stb_image;
diff --git a/components/gfx/paint_context.rs b/components/gfx/paint_context.rs
index 04551f08170..2098b5c9c19 100644
--- a/components/gfx/paint_context.rs
+++ b/components/gfx/paint_context.rs
@@ -23,11 +23,11 @@ use azure::azure_hl::{Pattern, PatternRef, Path, PathBuilder, CompositionOp, Ant
use azure::scaled_font::ScaledFont;
use azure::{AzFloat, struct__AzDrawOptions, struct__AzGlyph};
use azure::{struct__AzGlyphBuffer, struct__AzPoint, AzDrawTargetFillGlyphs};
-use geom::matrix2d::Matrix2D;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::side_offsets::SideOffsets2D;
-use geom::size::Size2D;
+use euclid::matrix2d::Matrix2D;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::side_offsets::SideOffsets2D;
+use euclid::size::Size2D;
use libc::types::common::c99::uint32_t;
use net_traits::image::base::Image;
use png::PixelsByColorType;
diff --git a/components/gfx/paint_task.rs b/components/gfx/paint_task.rs
index f640f56a541..b711b14e98e 100644
--- a/components/gfx/paint_task.rs
+++ b/components/gfx/paint_task.rs
@@ -12,10 +12,10 @@ use paint_context::PaintContext;
use azure::azure_hl::{SurfaceFormat, Color, DrawTarget, BackendType};
use azure::AzFloat;
-use geom::Matrix4;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
+use euclid::Matrix4;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
use layers::platform::surface::{NativeGraphicsMetadata, NativePaintingGraphicsContext};
use layers::platform::surface::NativeSurface;
use layers::layers::{BufferRequest, LayerBuffer, LayerBufferSet};
diff --git a/components/gfx/text/glyph.rs b/components/gfx/text/glyph.rs
index bc900960be9..ecc6374bedc 100644
--- a/components/gfx/text/glyph.rs
+++ b/components/gfx/text/glyph.rs
@@ -2,7 +2,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-use geom::point::Point2D;
+use euclid::point::Point2D;
use std::cmp::{Ordering, PartialOrd};
use std::iter::repeat;
use std::mem;
diff --git a/components/gfx/text/shaping/harfbuzz.rs b/components/gfx/text/shaping/harfbuzz.rs
index 3ab0582cac5..5850a5a3ab8 100644
--- a/components/gfx/text/shaping/harfbuzz.rs
+++ b/components/gfx/text/shaping/harfbuzz.rs
@@ -11,7 +11,7 @@ use text::glyph::{CharIndex, GlyphStore, GlyphId, GlyphData};
use text::shaping::ShaperMethods;
use text::util::{float_to_fixed, fixed_to_float};
-use geom::Point2D;
+use euclid::Point2D;
use harfbuzz::{HB_MEMORY_MODE_READONLY, HB_DIRECTION_LTR};
use harfbuzz::{RUST_hb_blob_create, RUST_hb_face_create_for_tables};
use harfbuzz::{hb_blob_t};
diff --git a/components/layout/Cargo.toml b/components/layout/Cargo.toml
index c4497f35c71..e0fa25dee0f 100644
--- a/components/layout/Cargo.toml
+++ b/components/layout/Cargo.toml
@@ -52,9 +52,6 @@ path = "../util"
[dependencies.selectors]
git = "https://github.com/servo/rust-selectors"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.png]
git = "https://github.com/servo/rust-png"
@@ -73,3 +70,4 @@ cssparser = "0.3.1"
smallvec = "0.1"
string_cache = "0.1"
string_cache_plugin = "0.1"
+euclid = "0.1"
diff --git a/components/layout/block.rs b/components/layout/block.rs
index 218dc9531ac..0ce4d5a9539 100644
--- a/components/layout/block.rs
+++ b/components/layout/block.rs
@@ -48,7 +48,7 @@ use model::{IntrinsicISizes, MarginCollapseInfo};
use model::{MaybeAuto, CollapsibleMargins, specified, specified_or_none};
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use gfx::display_list::{ClippingRegion, DisplayList};
use msg::compositor_msg::LayerId;
use rustc_serialize::{Encoder, Encodable};
diff --git a/components/layout/context.rs b/components/layout/context.rs
index b5ed8b729bc..f433c121f7e 100644
--- a/components/layout/context.rs
+++ b/components/layout/context.rs
@@ -11,7 +11,7 @@ use css::matching::{ApplicableDeclarationsCache, StyleSharingCandidateCache};
use canvas_traits::CanvasMsg;
use msg::compositor_msg::LayerId;
use fnv::FnvHasher;
-use geom::{Rect, Size2D};
+use euclid::{Rect, Size2D};
use gfx::display_list::OpaqueNode;
use gfx::font_cache_task::FontCacheTask;
use gfx::font_context::FontContext;
diff --git a/components/layout/display_list_builder.rs b/components/layout/display_list_builder.rs
index d749dc3f969..0ab4fe91fe1 100644
--- a/components/layout/display_list_builder.rs
+++ b/components/layout/display_list_builder.rs
@@ -21,8 +21,8 @@ use list_item::ListItemFlow;
use model::{self, MaybeAuto, ToGfxMatrix, ToAu};
use table_cell::CollapsedBordersForCell;
-use geom::{Point2D, Rect, Size2D, SideOffsets2D};
-use geom::Matrix4;
+use euclid::{Point2D, Rect, Size2D, SideOffsets2D};
+use euclid::Matrix4;
use gfx_traits::color;
use gfx::display_list::{BLUR_INFLATION_FACTOR, BaseDisplayItem, BorderDisplayItem};
use gfx::display_list::{BorderRadii, BoxShadowClipMode, BoxShadowDisplayItem, ClippingRegion};
diff --git a/components/layout/flow.rs b/components/layout/flow.rs
index eae78fef05c..5d10a6d9fca 100644
--- a/components/layout/flow.rs
+++ b/components/layout/flow.rs
@@ -47,7 +47,7 @@ use table_wrapper::TableWrapperFlow;
use multicol::MulticolFlow;
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use gfx::display_list::ClippingRegion;
use msg::compositor_msg::LayerId;
use msg::constellation_msg::ConstellationChan;
diff --git a/components/layout/fragment.rs b/components/layout/fragment.rs
index b6af941eceb..36225040c4e 100644
--- a/components/layout/fragment.rs
+++ b/components/layout/fragment.rs
@@ -21,7 +21,7 @@ use text;
use opaque_node::OpaqueNodeMethods;
use wrapper::{TLayoutNode, ThreadSafeLayoutNode};
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use gfx::display_list::{BLUR_INFLATION_FACTOR, OpaqueNode};
use gfx::text::glyph::CharIndex;
use gfx::text::text_run::{TextRun, TextRunSlice};
diff --git a/components/layout/inline.rs b/components/layout/inline.rs
index 028626e803f..93a62c484c0 100644
--- a/components/layout/inline.rs
+++ b/components/layout/inline.rs
@@ -17,7 +17,7 @@ use layout_debug;
use model::IntrinsicISizesContribution;
use text;
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use gfx::display_list::OpaqueNode;
use gfx::font::FontMetrics;
use gfx::font_context::FontContext;
diff --git a/components/layout/layout_task.rs b/components/layout/layout_task.rs
index 19588819c95..ec5a37df70c 100644
--- a/components/layout/layout_task.rs
+++ b/components/layout/layout_task.rs
@@ -28,11 +28,11 @@ use canvas_traits::CanvasMsg;
use encoding::EncodingRef;
use encoding::all::UTF_8;
use fnv::FnvHasher;
-use geom::Matrix4;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::scale_factor::ScaleFactor;
-use geom::size::Size2D;
+use euclid::Matrix4;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::Size2D;
use gfx_traits::color;
use gfx::display_list::{ClippingRegion, DisplayItemMetadata, DisplayList, OpaqueNode};
use gfx::display_list::{StackingContext};
diff --git a/components/layout/lib.rs b/components/layout/lib.rs
index 18474898421..dd3f6bec269 100644
--- a/components/layout/lib.rs
+++ b/components/layout/lib.rs
@@ -42,7 +42,7 @@ extern crate clock_ticks;
extern crate cssparser;
extern crate encoding;
extern crate fnv;
-extern crate geom;
+extern crate euclid;
extern crate gfx;
extern crate gfx_traits;
extern crate layout_traits;
diff --git a/components/layout/list_item.rs b/components/layout/list_item.rs
index d38b365f144..86775638c27 100644
--- a/components/layout/list_item.rs
+++ b/components/layout/list_item.rs
@@ -19,7 +19,7 @@ use inline::InlineMetrics;
use text;
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use gfx::display_list::DisplayList;
use util::geometry::Au;
use util::logical_geometry::LogicalSize;
diff --git a/components/layout/model.rs b/components/layout/model.rs
index b5adaf1a681..d6587a13a4c 100644
--- a/components/layout/model.rs
+++ b/components/layout/model.rs
@@ -8,7 +8,7 @@
use fragment::Fragment;
-use geom::{Matrix4, SideOffsets2D};
+use euclid::{Matrix4, SideOffsets2D};
use std::cmp::{max, min};
use std::fmt;
use style::computed_values::transform::ComputedMatrix;
diff --git a/components/layout/multicol.rs b/components/layout/multicol.rs
index 1ce84a365f1..bf4e4e11ea8 100644
--- a/components/layout/multicol.rs
+++ b/components/layout/multicol.rs
@@ -13,7 +13,7 @@ use flow::{FlowClass, Flow, OpaqueFlow};
use fragment::{Fragment, FragmentBorderBoxIterator};
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use util::geometry::Au;
use util::logical_geometry::LogicalSize;
use std::fmt;
diff --git a/components/layout/sequential.rs b/components/layout/sequential.rs
index 74522354e7d..7ebd8a407e6 100644
--- a/components/layout/sequential.rs
+++ b/components/layout/sequential.rs
@@ -17,7 +17,7 @@ use wrapper::LayoutNode;
use wrapper::{PostorderNodeMutTraversal};
use wrapper::{PreorderDomTraversal, PostorderDomTraversal};
-use geom::point::Point2D;
+use euclid::point::Point2D;
use util::geometry::{Au, ZERO_POINT};
use util::opts;
diff --git a/components/layout/table.rs b/components/layout/table.rs
index 9bb86eb9129..09a89cee466 100644
--- a/components/layout/table.rs
+++ b/components/layout/table.rs
@@ -21,7 +21,7 @@ use table_row::{TableRowFlow};
use table_wrapper::TableLayout;
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use gfx::display_list::DisplayList;
use std::cmp;
use std::fmt;
diff --git a/components/layout/table_caption.rs b/components/layout/table_caption.rs
index ab98e9b3261..c840ab866ce 100644
--- a/components/layout/table_caption.rs
+++ b/components/layout/table_caption.rs
@@ -12,7 +12,7 @@ use flow::{FlowClass, Flow, OpaqueFlow};
use fragment::{Fragment, FragmentBorderBoxIterator};
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use util::geometry::Au;
use util::logical_geometry::LogicalSize;
use std::fmt;
diff --git a/components/layout/table_cell.rs b/components/layout/table_cell.rs
index 3f8b32254f8..f72f3f30e79 100644
--- a/components/layout/table_cell.rs
+++ b/components/layout/table_cell.rs
@@ -19,7 +19,7 @@ use table_row::{CollapsedBorder, CollapsedBorderProvenance};
use wrapper::ThreadSafeLayoutNode;
use cssparser::Color;
-use geom::{Point2D, Rect, SideOffsets2D, Size2D};
+use euclid::{Point2D, Rect, SideOffsets2D, Size2D};
use gfx::display_list::DisplayList;
use std::fmt;
use std::sync::Arc;
diff --git a/components/layout/table_colgroup.rs b/components/layout/table_colgroup.rs
index bd9dd597a3b..90e7c329e68 100644
--- a/components/layout/table_colgroup.rs
+++ b/components/layout/table_colgroup.rs
@@ -13,7 +13,7 @@ use fragment::{Fragment, FragmentBorderBoxIterator, SpecificFragmentInfo};
use layout_debug;
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use util::geometry::{Au, ZERO_RECT};
use std::cmp::max;
use std::fmt;
diff --git a/components/layout/table_row.rs b/components/layout/table_row.rs
index ee9411a0513..5048644b755 100644
--- a/components/layout/table_row.rs
+++ b/components/layout/table_row.rs
@@ -19,7 +19,7 @@ use model::MaybeAuto;
use wrapper::ThreadSafeLayoutNode;
use cssparser::{Color, RGBA};
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use gfx::display_list::DisplayList;
use rustc_serialize::{Encoder, Encodable};
use std::cmp::max;
diff --git a/components/layout/table_rowgroup.rs b/components/layout/table_rowgroup.rs
index 2c76c30c832..51c700ae480 100644
--- a/components/layout/table_rowgroup.rs
+++ b/components/layout/table_rowgroup.rs
@@ -16,7 +16,7 @@ use table::{ColumnComputedInlineSize, ColumnIntrinsicInlineSize, InternalTable,
use table_row::{self, CollapsedBordersForRow};
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use rustc_serialize::{Encoder, Encodable};
use std::fmt;
use std::iter::{IntoIterator, Iterator, Peekable};
diff --git a/components/layout/table_wrapper.rs b/components/layout/table_wrapper.rs
index 8f77e97dfd0..80a3bc71ae9 100644
--- a/components/layout/table_wrapper.rs
+++ b/components/layout/table_wrapper.rs
@@ -25,7 +25,7 @@ use table::{ColumnComputedInlineSize, ColumnIntrinsicInlineSize};
use table_row;
use wrapper::ThreadSafeLayoutNode;
-use geom::{Point2D, Rect};
+use euclid::{Point2D, Rect};
use util::geometry::Au;
use util::logical_geometry::LogicalSize;
use std::cmp::{max, min};
diff --git a/components/layout_traits/Cargo.toml b/components/layout_traits/Cargo.toml
index e19ce0ca7e1..888f729bea2 100644
--- a/components/layout_traits/Cargo.toml
+++ b/components/layout_traits/Cargo.toml
@@ -7,9 +7,6 @@ authors = ["The Servo Project Developers"]
name = "layout_traits"
path = "lib.rs"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.gfx]
path = "../gfx"
@@ -30,3 +27,4 @@ path = "../util"
[dependencies]
url = "0.2.35"
+euclid = "0.1"
diff --git a/components/layout_traits/lib.rs b/components/layout_traits/lib.rs
index df60e189438..7db5475c969 100644
--- a/components/layout_traits/lib.rs
+++ b/components/layout_traits/lib.rs
@@ -2,7 +2,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-extern crate geom;
+extern crate euclid;
extern crate gfx;
extern crate script_traits;
extern crate msg;
@@ -16,7 +16,7 @@ extern crate util;
// The traits are here instead of in layout so
// that these modules won't have to depend on layout.
-use geom::rect::Rect;
+use euclid::rect::Rect;
use gfx::font_cache_task::FontCacheTask;
use gfx::paint_task::PaintChan;
use msg::compositor_msg::{Epoch, LayerId};
diff --git a/components/msg/Cargo.toml b/components/msg/Cargo.toml
index 395c569913f..081dea247b0 100644
--- a/components/msg/Cargo.toml
+++ b/components/msg/Cargo.toml
@@ -16,9 +16,6 @@ path = "../util"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -30,6 +27,7 @@ url = "0.2.35"
bitflags = "*"
hyper = "0.5"
rustc-serialize = "0.3.4"
+euclid = "0.1"
[target.x86_64-apple-darwin.dependencies]
core-foundation = "*"
diff --git a/components/msg/compositor_msg.rs b/components/msg/compositor_msg.rs
index 526ac86018b..f6af5e02f22 100644
--- a/components/msg/compositor_msg.rs
+++ b/components/msg/compositor_msg.rs
@@ -4,8 +4,8 @@
use azure::azure_hl::Color;
use constellation_msg::{Key, KeyState, KeyModifiers};
-use geom::point::Point2D;
-use geom::rect::Rect;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
use layers::platform::surface::NativeGraphicsMetadata;
use layers::layers::LayerBufferSet;
use std::fmt::{Formatter, Debug};
diff --git a/components/msg/constellation_msg.rs b/components/msg/constellation_msg.rs
index 16a68dc7532..a25a9c318e2 100644
--- a/components/msg/constellation_msg.rs
+++ b/components/msg/constellation_msg.rs
@@ -6,9 +6,9 @@
//! reduce coupling between these two components.
use compositor_msg::Epoch;
-use geom::rect::Rect;
-use geom::size::TypedSize2D;
-use geom::scale_factor::ScaleFactor;
+use euclid::rect::Rect;
+use euclid::size::TypedSize2D;
+use euclid::scale_factor::ScaleFactor;
use hyper::header::Headers;
use hyper::method::Method;
use layers::geometry::DevicePixel;
diff --git a/components/msg/lib.rs b/components/msg/lib.rs
index 52fa7fe4817..3e8427840d5 100644
--- a/components/msg/lib.rs
+++ b/components/msg/lib.rs
@@ -4,7 +4,7 @@
extern crate azure;
#[macro_use] extern crate bitflags;
-extern crate geom;
+extern crate euclid;
extern crate hyper;
extern crate layers;
extern crate png;
diff --git a/components/net/Cargo.toml b/components/net/Cargo.toml
index 1b3d96b8771..b99d107d038 100644
--- a/components/net/Cargo.toml
+++ b/components/net/Cargo.toml
@@ -16,9 +16,6 @@ path = "../util"
[dependencies.devtools_traits]
path = "../devtools_traits"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.png]
git = "https://github.com/servo/rust-png"
@@ -34,3 +31,4 @@ regex_macros = "0.1.8"
hyper = "0.5"
flate2 = "0.2.0"
uuid = "0.1.16"
+euclid = "0.1"
diff --git a/components/net/lib.rs b/components/net/lib.rs
index 5f5123c6106..27b7cba4e98 100644
--- a/components/net/lib.rs
+++ b/components/net/lib.rs
@@ -16,7 +16,7 @@ extern crate net_traits;
extern crate cookie as cookie_rs;
extern crate devtools_traits;
extern crate flate2;
-extern crate geom;
+extern crate euclid;
extern crate hyper;
extern crate png;
#[macro_use]
diff --git a/components/net_traits/Cargo.toml b/components/net_traits/Cargo.toml
index 1500ef4f406..3bfe8910cb2 100644
--- a/components/net_traits/Cargo.toml
+++ b/components/net_traits/Cargo.toml
@@ -7,9 +7,6 @@ authors = ["The Servo Project Developers"]
name = "net_traits"
path = "lib.rs"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.png]
git = "https://github.com/servo/rust-png"
@@ -26,3 +23,5 @@ git = "https://github.com/servo/rust-stb-image"
log = "*"
url = "0.2.35"
hyper = "0.5"
+euclid = "0.1"
+
diff --git a/components/net_traits/lib.rs b/components/net_traits/lib.rs
index 5c6a0cd9df8..cc5ba727453 100644
--- a/components/net_traits/lib.rs
+++ b/components/net_traits/lib.rs
@@ -7,7 +7,7 @@
#![feature(slice_patterns)]
#![feature(step_by)]
-extern crate geom;
+extern crate euclid;
extern crate hyper;
#[macro_use]
extern crate log;
diff --git a/components/script/Cargo.toml b/components/script/Cargo.toml
index 6d08b21bcec..31be05ac9bb 100644
--- a/components/script/Cargo.toml
+++ b/components/script/Cargo.toml
@@ -48,9 +48,6 @@ path = "../canvas_traits"
[dependencies.selectors]
git = "https://github.com/servo/rust-selectors"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.js]
git = "https://github.com/servo/rust-mozjs"
@@ -82,3 +79,4 @@ smallvec = "0.1"
html5ever = "0.1"
string_cache = "0.1"
string_cache_plugin = "0.1"
+euclid = "0.1"
diff --git a/components/script/dom/bindings/trace.rs b/components/script/dom/bindings/trace.rs
index a4ef3eb6d9b..6a0f72412de 100644
--- a/components/script/dom/bindings/trace.rs
+++ b/components/script/dom/bindings/trace.rs
@@ -38,9 +38,9 @@ use canvas_traits::{CanvasGradientStop, LinearGradientStyle, RadialGradientStyle
use canvas_traits::{LineCapStyle, LineJoinStyle, CompositionOrBlending, RepetitionStyle};
use cssparser::RGBA;
use encoding::types::EncodingRef;
-use geom::matrix2d::Matrix2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
+use euclid::matrix2d::Matrix2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
use html5ever::tree_builder::QuirksMode;
use hyper::header::Headers;
use hyper::method::Method;
diff --git a/components/script/dom/canvaspattern.rs b/components/script/dom/canvaspattern.rs
index 0be707a1147..b97ba6bb76e 100644
--- a/components/script/dom/canvaspattern.rs
+++ b/components/script/dom/canvaspattern.rs
@@ -8,7 +8,7 @@ use dom::bindings::global::GlobalRef;
use dom::bindings::js::{JSRef, Temporary};
use dom::bindings::utils::{Reflector, reflect_dom_object};
use dom::canvasgradient::ToFillOrStrokeStyle;
-use geom::size::Size2D;
+use euclid::size::Size2D;
// https://html.spec.whatwg.org/multipage/#canvaspattern
#[dom_struct]
diff --git a/components/script/dom/canvasrenderingcontext2d.rs b/components/script/dom/canvasrenderingcontext2d.rs
index 9ac3a97c55b..06330b48889 100644
--- a/components/script/dom/canvasrenderingcontext2d.rs
+++ b/components/script/dom/canvasrenderingcontext2d.rs
@@ -24,10 +24,10 @@ use dom::node::{window_from_node, NodeHelpers, NodeDamage};
use cssparser::Color as CSSColor;
use cssparser::{Parser, RGBA};
-use geom::matrix2d::Matrix2D;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
+use euclid::matrix2d::Matrix2D;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
use canvas_traits::{CanvasMsg, Canvas2dMsg, CanvasCommonMsg};
use canvas_traits::{FillOrStrokeStyle, LinearGradientStyle, RadialGradientStyle, RepetitionStyle};
diff --git a/components/script/dom/document.rs b/components/script/dom/document.rs
index 18b50faff5d..f009e4d1cdc 100644
--- a/components/script/dom/document.rs
+++ b/components/script/dom/document.rs
@@ -82,7 +82,7 @@ use util::opts;
use util::str::{DOMString, split_html_space_chars};
use layout_interface::{ReflowGoal, ReflowQueryType};
-use geom::point::Point2D;
+use euclid::point::Point2D;
use html5ever::tree_builder::{QuirksMode, NoQuirks, LimitedQuirks, Quirks};
use layout_interface::{LayoutChan, Msg};
use string_cache::{Atom, QualName};
diff --git a/components/script/dom/htmlcanvaselement.rs b/components/script/dom/htmlcanvaselement.rs
index f0367679e25..1b3c8261bd3 100644
--- a/components/script/dom/htmlcanvaselement.rs
+++ b/components/script/dom/htmlcanvaselement.rs
@@ -31,7 +31,7 @@ use js::jsapi::{JSContext};
use js::jsval::JSVal;
use offscreen_gl_context::GLContextAttributes;
-use geom::size::Size2D;
+use euclid::size::Size2D;
use std::cell::Cell;
use std::default::Default;
diff --git a/components/script/dom/imagedata.rs b/components/script/dom/imagedata.rs
index c935c51adcd..04c99d08a64 100644
--- a/components/script/dom/imagedata.rs
+++ b/components/script/dom/imagedata.rs
@@ -7,7 +7,7 @@ use dom::bindings::codegen::Bindings::ImageDataBinding::ImageDataMethods;
use dom::bindings::global::GlobalRef;
use dom::bindings::js::{JSRef, Temporary};
use dom::bindings::utils::{Reflector, reflect_dom_object};
-use geom::size::Size2D;
+use euclid::size::Size2D;
use js::jsapi::{JSContext, JSObject};
use js::jsfriendapi::bindgen::{JS_NewUint8ClampedArray, JS_GetUint8ClampedArrayData};
use libc::uint8_t;
diff --git a/components/script/dom/node.rs b/components/script/dom/node.rs
index 97a4212f35a..d971028fcec 100644
--- a/components/script/dom/node.rs
+++ b/components/script/dom/node.rs
@@ -46,7 +46,7 @@ use dom::processinginstruction::{ProcessingInstruction, ProcessingInstructionHel
use dom::text::Text;
use dom::virtualmethods::{VirtualMethods, vtable_for};
use dom::window::{Window, WindowHelpers};
-use geom::rect::Rect;
+use euclid::rect::Rect;
use layout_interface::{LayoutChan, Msg};
use devtools_traits::NodeInfo;
use parse::html::parse_html_fragment;
diff --git a/components/script/dom/webglrenderingcontext.rs b/components/script/dom/webglrenderingcontext.rs
index 786a3c25620..a2745aaa143 100644
--- a/components/script/dom/webglrenderingcontext.rs
+++ b/components/script/dom/webglrenderingcontext.rs
@@ -19,7 +19,7 @@ use dom::webgltexture::{WebGLTexture, WebGLTextureHelpers};
use dom::webglshader::{WebGLShader, WebGLShaderHelpers};
use dom::webglprogram::{WebGLProgram, WebGLProgramHelpers};
use dom::webgluniformlocation::{WebGLUniformLocation, WebGLUniformLocationHelpers};
-use geom::size::Size2D;
+use euclid::size::Size2D;
use js::jsapi::{JSContext, JSObject};
use js::jsfriendapi::bindgen::{JS_GetFloat32ArrayData, JS_GetObjectAsArrayBufferView};
use js::jsval::{JSVal, NullValue, Int32Value};
diff --git a/components/script/dom/window.rs b/components/script/dom/window.rs
index c6de7bcca82..5f1849c436c 100644
--- a/components/script/dom/window.rs
+++ b/components/script/dom/window.rs
@@ -48,7 +48,7 @@ use util::geometry::{self, Au, MAX_RECT};
use util::opts;
use util::str::{DOMString,HTML_SPACE_CHARACTERS};
-use geom::{Point2D, Rect, Size2D};
+use euclid::{Point2D, Rect, Size2D};
use js::jsapi::JS_EvaluateUCScript;
use js::jsapi::JSContext;
use js::jsapi::{JS_GC, JS_GetRuntime};
diff --git a/components/script/layout_interface.rs b/components/script/layout_interface.rs
index 2ebb00d5cf8..b88f60c6b4e 100644
--- a/components/script/layout_interface.rs
+++ b/components/script/layout_interface.rs
@@ -8,8 +8,8 @@
use dom::node::LayoutData;
-use geom::point::Point2D;
-use geom::rect::Rect;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
use libc::uintptr_t;
use msg::compositor_msg::LayerId;
use msg::constellation_msg::{PipelineExitType, WindowSizeData};
diff --git a/components/script/lib.rs b/components/script/lib.rs
index a51d10fea35..6836895d5e7 100644
--- a/components/script/lib.rs
+++ b/components/script/lib.rs
@@ -25,7 +25,7 @@ extern crate log;
extern crate core;
extern crate devtools_traits;
extern crate cssparser;
-extern crate geom;
+extern crate euclid;
extern crate html5ever;
extern crate encoding;
extern crate fnv;
diff --git a/components/script/script_task.rs b/components/script/script_task.rs
index 323954521d6..df424807c56 100644
--- a/components/script/script_task.rs
+++ b/components/script/script_task.rs
@@ -77,8 +77,8 @@ use util::str::DOMString;
use util::task::spawn_named_with_send_on_failure;
use util::task_state;
-use geom::Rect;
-use geom::point::Point2D;
+use euclid::Rect;
+use euclid::point::Point2D;
use hyper::header::{LastModified, Headers};
use js::jsapi::{JS_SetWrapObjectCallbacks, JS_SetExtraGCRootsTracer};
use js::jsapi::{JSContext, JSRuntime, JSObject, JSTracer};
diff --git a/components/script_traits/Cargo.toml b/components/script_traits/Cargo.toml
index 0404ca63366..72b968cf20f 100644
--- a/components/script_traits/Cargo.toml
+++ b/components/script_traits/Cargo.toml
@@ -19,9 +19,7 @@ path = "../util"
[dependencies.devtools_traits]
path = "../devtools_traits"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies]
url = "0.2.35"
libc = "*"
+euclid = "0.1"
diff --git a/components/script_traits/lib.rs b/components/script_traits/lib.rs
index 960e60a6af0..20fe580fdba 100644
--- a/components/script_traits/lib.rs
+++ b/components/script_traits/lib.rs
@@ -9,7 +9,7 @@
#[deny(missing_docs)]
extern crate devtools_traits;
-extern crate geom;
+extern crate euclid;
extern crate libc;
extern crate msg;
extern crate net_traits;
@@ -30,8 +30,8 @@ use std::any::Any;
use std::sync::mpsc::{Sender, Receiver};
use url::Url;
-use geom::point::Point2D;
-use geom::rect::Rect;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
/// The address of a node. Layout sends these back. They must be validated via
/// `from_untrusted_node_address` before they can be used, because we do not trust layout.
diff --git a/components/servo/Cargo.lock b/components/servo/Cargo.lock
index c074e40ac8d..10ff5f381ac 100644
--- a/components/servo/Cargo.lock
+++ b/components/servo/Cargo.lock
@@ -42,15 +42,15 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
name = "azure"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-azure#0e864697513c9e31bbe2213957d5713fd6139e69"
+source = "git+https://github.com/servo/rust-azure#d4ae702d7525a560d15e08238c7b7b75c093209d"
dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
"freetype-sys 2.4.11 (git+https://github.com/servo/libfreetype2)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"skia 0.0.20130412 (git+https://github.com/servo/skia)",
"x11 1.1.1 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -78,7 +78,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"canvas_traits 0.0.1",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -94,7 +94,7 @@ version = "0.0.1"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"offscreen_gl_context 0.0.1 (git+https://github.com/ecoal95/rust-offscreen-rendering-context)",
@@ -145,7 +145,7 @@ dependencies = [
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -320,6 +320,17 @@ dependencies = [
]
[[package]]
+name = "euclid"
+version = "0.1.0"
+source = "registry+https://github.com/rust-lang/crates.io-index"
+dependencies = [
+ "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
+ "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
+]
+
+[[package]]
name = "expat-sys"
version = "2.1.0"
source = "git+https://github.com/servo/libexpat#83f914d964af73ba38aa413455a2009cc6cb2618"
@@ -383,17 +394,6 @@ dependencies = [
]
[[package]]
-name = "geom"
-version = "0.1.0"
-source = "git+https://github.com/servo/rust-geom#16b91afc0b9b532f2fb56879069bc381f2143df1"
-dependencies = [
- "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
- "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
- "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
-]
-
-[[package]]
name = "gfx"
version = "0.0.1"
dependencies = [
@@ -403,10 +403,10 @@ dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fontconfig 0.1.0 (git+https://github.com/servo/rust-fontconfig)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx_traits 0.0.1",
"harfbuzz 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -504,7 +504,7 @@ dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"compositing 0.0.1",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glutin 0.0.26 (git+https://github.com/servo/glutin?branch=servo)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -588,11 +588,11 @@ dependencies = [
[[package]]
name = "io-surface"
version = "0.1.0"
-source = "git+https://github.com/servo/io-surface-rs#7f8d819c7c2cef9ba6e057478bc13f01fe5e5a96"
+source = "git+https://github.com/servo/io-surface-rs#401cf1d0a90290aa832b622061257d2ce985f69b"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
]
@@ -625,13 +625,13 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
name = "layers"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-layers#76d90799f152a78c35c90d9d7a9311a68e98937a"
+source = "git+https://github.com/servo/rust-layers#65001b9e18631172a457c31c04be990639c02c35"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
@@ -653,8 +653,8 @@ dependencies = [
"clock_ticks 0.0.6 (git+https://github.com/tomaka/clock_ticks)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"layout_traits 0.0.1",
@@ -681,7 +681,7 @@ dependencies = [
name = "layout_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -764,7 +764,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -781,8 +781,8 @@ version = "0.0.1"
dependencies = [
"cookie 0.1.21 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"flate2 0.2.7 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"net_traits 0.0.1",
@@ -813,7 +813,7 @@ dependencies = [
name = "net_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
@@ -852,12 +852,12 @@ dependencies = [
[[package]]
name = "offscreen_gl_context"
version = "0.0.1"
-source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#5d126b050569545204ddb5b9101be64850ebfe5a"
+source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#e79da8f61ad468087beb546bca4d7267b77edd9f"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -1034,8 +1034,8 @@ dependencies = [
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"html5ever 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1077,7 +1077,7 @@ name = "script_traits"
version = "0.0.1"
dependencies = [
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -1166,8 +1166,8 @@ dependencies = [
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"matches 0.1.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1187,7 +1187,7 @@ name = "style_tests"
version = "0.0.1"
dependencies = [
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"selectors 0.1.0 (git+https://github.com/servo/rust-selectors)",
"string_cache 0.1.3 (registry+https://github.com/rust-lang/crates.io-index)",
"string_cache_plugin 0.1.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1266,7 +1266,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1288,7 +1288,7 @@ dependencies = [
name = "util_tests"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"plugins 0.0.1",
"util 0.0.1",
diff --git a/components/style/Cargo.toml b/components/style/Cargo.toml
index e837ef8adf5..1b8474f18bd 100644
--- a/components/style/Cargo.toml
+++ b/components/style/Cargo.toml
@@ -15,8 +15,6 @@ path = "../plugins"
[dependencies.util]
path = "../util"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
[dependencies.selectors]
git = "https://github.com/servo/rust-selectors"
@@ -35,3 +33,4 @@ lazy_static = "0.1.10"
smallvec = "0.1"
string_cache = "0.1"
string_cache_plugin = "0.1"
+euclid = "0.1"
diff --git a/components/style/lib.rs b/components/style/lib.rs
index b044317f1cb..4867bac20c0 100644
--- a/components/style/lib.rs
+++ b/components/style/lib.rs
@@ -16,7 +16,7 @@
#[macro_use] extern crate bitflags;
extern crate fnv;
-extern crate geom;
+extern crate euclid;
extern crate smallvec;
extern crate url;
diff --git a/components/style/media_queries.rs b/components/style/media_queries.rs
index a63fea173ff..9fa4a921d0f 100644
--- a/components/style/media_queries.rs
+++ b/components/style/media_queries.rs
@@ -5,7 +5,7 @@
use std::ascii::AsciiExt;
use cssparser::{Token, Parser, Delimiter};
-use geom::size::{Size2D, TypedSize2D};
+use euclid::size::{Size2D, TypedSize2D};
use properties::longhands;
use util::geometry::{Au, ViewportPx};
use values::specified;
diff --git a/components/style/properties.mako.rs b/components/style/properties.mako.rs
index 93b95a60e80..78ff721e8a6 100644
--- a/components/style/properties.mako.rs
+++ b/components/style/properties.mako.rs
@@ -22,8 +22,8 @@ use url::Url;
use cssparser::{Parser, Color, RGBA, AtRuleParser, DeclarationParser,
DeclarationListParser, parse_important, ToCss};
use fnv::FnvHasher;
-use geom::SideOffsets2D;
-use geom::size::Size2D;
+use euclid::SideOffsets2D;
+use euclid::size::Size2D;
use values::specified::{Length, BorderStyle};
use values::computed::{self, ToComputedValue};
@@ -3747,7 +3747,7 @@ pub mod longhands {
use self::computed_value::{StartEnd, TransitionTimingFunction};
use values::computed::{Context, ToComputedValue};
- use geom::point::Point2D;
+ use euclid::point::Point2D;
pub use self::computed_value::SingleComputedValue as SingleSpecifiedValue;
pub use self::computed_value::T as SpecifiedValue;
@@ -3795,7 +3795,7 @@ pub mod longhands {
pub mod computed_value {
use cssparser::ToCss;
- use geom::point::Point2D;
+ use euclid::point::Point2D;
use std::fmt;
pub use self::TransitionTimingFunction as SingleComputedValue;
diff --git a/components/style/values.rs b/components/style/values.rs
index fde7f715689..d6ccb0480be 100644
--- a/components/style/values.rs
+++ b/components/style/values.rs
@@ -80,7 +80,7 @@ pub mod specified {
use std::ops::{Add, Mul};
use url::Url;
use cssparser::{self, Token, Parser, ToCss, CssStringWriter};
- use geom::size::Size2D;
+ use euclid::size::Size2D;
use parser::ParserContext;
use util::geometry::Au;
use super::CSSFloat;
@@ -892,7 +892,7 @@ pub mod computed {
use super::specified::{AngleOrCorner};
use super::{specified, CSSFloat};
pub use cssparser::Color as CSSColor;
- use geom::size::Size2D;
+ use euclid::size::Size2D;
use properties::longhands;
use std::fmt;
use std::ops::{Add, Mul};
diff --git a/components/style/viewport.rs b/components/style/viewport.rs
index 176ad77e6fc..100879a1621 100644
--- a/components/style/viewport.rs
+++ b/components/style/viewport.rs
@@ -3,8 +3,8 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
use cssparser::{Parser, DeclarationListParser, AtRuleParser, DeclarationParser, ToCss, parse_important};
-use geom::size::{Size2D, TypedSize2D};
-use geom::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
+use euclid::scale_factor::ScaleFactor;
use parser::{ParserContext, log_css_error};
use properties::longhands;
use stylesheets::Origin;
diff --git a/components/util/Cargo.toml b/components/util/Cargo.toml
index 9fcf9be6d6e..674344a7ac6 100644
--- a/components/util/Cargo.toml
+++ b/components/util/Cargo.toml
@@ -24,9 +24,6 @@ git = "https://github.com/servo/rust-selectors"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -45,3 +42,4 @@ lazy_static = "0.1.10"
url = "*"
string_cache = "0.1"
string_cache_plugin = "0.1"
+euclid = "0.1"
diff --git a/components/util/bezier.rs b/components/util/bezier.rs
index 28251745cbc..668f6bc0321 100644
--- a/components/util/bezier.rs
+++ b/components/util/bezier.rs
@@ -6,7 +6,7 @@
//!
//! This is based on `WebCore/platform/graphics/UnitBezier.h` in WebKit.
-use geom::point::Point2D;
+use euclid::point::Point2D;
const NEWTON_METHOD_ITERATIONS: u8 = 8;
diff --git a/components/util/lib.rs b/components/util/lib.rs
index 28c285b97a7..77273a35d07 100644
--- a/components/util/lib.rs
+++ b/components/util/lib.rs
@@ -24,7 +24,7 @@ extern crate azure;
extern crate alloc;
#[macro_use] extern crate bitflags;
#[macro_use] extern crate cssparser;
-extern crate geom;
+extern crate euclid;
extern crate getopts;
extern crate layers;
extern crate libc;
diff --git a/components/util/logical_geometry.rs b/components/util/logical_geometry.rs
index 02739ab4548..088cf444cab 100644
--- a/components/util/logical_geometry.rs
+++ b/components/util/logical_geometry.rs
@@ -4,8 +4,8 @@
//! Geometry in flow-relative space.
-use geom::{Size2D, Point2D, SideOffsets2D, Rect};
-use geom::num::Zero;
+use euclid::{Size2D, Point2D, SideOffsets2D, Rect};
+use euclid::num::Zero;
use std::cmp::{min, max};
use std::fmt::{self, Debug, Formatter, Error};
use std::ops::{Add, Sub};
diff --git a/components/util/mem.rs b/components/util/mem.rs
index 0170a1b359f..87c61652a60 100644
--- a/components/util/mem.rs
+++ b/components/util/mem.rs
@@ -13,7 +13,7 @@ use std::sync::Arc;
use azure::azure_hl::Color;
use cursor::Cursor;
-use geom::{Point2D, Rect, SideOffsets2D, Size2D, Matrix2D, Matrix4};
+use euclid::{Point2D, Rect, SideOffsets2D, Size2D, Matrix2D, Matrix4};
use geometry::Au;
use range::Range;
diff --git a/components/util/opts.rs b/components/util/opts.rs
index d5c91e64fb6..dbddcfe0f98 100644
--- a/components/util/opts.rs
+++ b/components/util/opts.rs
@@ -7,8 +7,8 @@
use geometry::ScreenPx;
-use geom::scale_factor::ScaleFactor;
-use geom::size::{Size2D, TypedSize2D};
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
use layers::geometry::DevicePixel;
use getopts;
use num_cpus;
diff --git a/ports/cef/Cargo.lock b/ports/cef/Cargo.lock
index 955a86dc379..e68b1abf8d5 100644
--- a/ports/cef/Cargo.lock
+++ b/ports/cef/Cargo.lock
@@ -10,7 +10,7 @@ dependencies = [
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"devtools 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glutin_app 0.0.1",
@@ -41,15 +41,15 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
name = "azure"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-azure#0e864697513c9e31bbe2213957d5713fd6139e69"
+source = "git+https://github.com/servo/rust-azure#d4ae702d7525a560d15e08238c7b7b75c093209d"
dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
"freetype-sys 2.4.11 (git+https://github.com/servo/libfreetype2)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"skia 0.0.20130412 (git+https://github.com/servo/skia)",
"x11 1.1.1 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -77,7 +77,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"canvas_traits 0.0.1",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -93,7 +93,7 @@ version = "0.0.1"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"offscreen_gl_context 0.0.1 (git+https://github.com/ecoal95/rust-offscreen-rendering-context)",
@@ -144,7 +144,7 @@ dependencies = [
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -319,6 +319,17 @@ dependencies = [
]
[[package]]
+name = "euclid"
+version = "0.1.0"
+source = "registry+https://github.com/rust-lang/crates.io-index"
+dependencies = [
+ "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
+ "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
+]
+
+[[package]]
name = "expat-sys"
version = "2.1.0"
source = "git+https://github.com/servo/libexpat#83f914d964af73ba38aa413455a2009cc6cb2618"
@@ -382,17 +393,6 @@ dependencies = [
]
[[package]]
-name = "geom"
-version = "0.1.0"
-source = "git+https://github.com/servo/rust-geom#16b91afc0b9b532f2fb56879069bc381f2143df1"
-dependencies = [
- "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
- "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
- "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
-]
-
-[[package]]
name = "gfx"
version = "0.0.1"
dependencies = [
@@ -402,10 +402,10 @@ dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fontconfig 0.1.0 (git+https://github.com/servo/rust-fontconfig)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx_traits 0.0.1",
"harfbuzz 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -496,7 +496,7 @@ dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"compositing 0.0.1",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glutin 0.0.26 (git+https://github.com/servo/glutin?branch=servo)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -580,11 +580,11 @@ dependencies = [
[[package]]
name = "io-surface"
version = "0.1.0"
-source = "git+https://github.com/servo/io-surface-rs#7f8d819c7c2cef9ba6e057478bc13f01fe5e5a96"
+source = "git+https://github.com/servo/io-surface-rs#401cf1d0a90290aa832b622061257d2ce985f69b"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
]
@@ -617,13 +617,13 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
name = "layers"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-layers#76d90799f152a78c35c90d9d7a9311a68e98937a"
+source = "git+https://github.com/servo/rust-layers#65001b9e18631172a457c31c04be990639c02c35"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
@@ -645,8 +645,8 @@ dependencies = [
"clock_ticks 0.0.6 (git+https://github.com/tomaka/clock_ticks)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"layout_traits 0.0.1",
@@ -673,7 +673,7 @@ dependencies = [
name = "layout_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -756,7 +756,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -773,8 +773,8 @@ version = "0.0.1"
dependencies = [
"cookie 0.1.21 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"flate2 0.2.7 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"net_traits 0.0.1",
@@ -793,7 +793,7 @@ dependencies = [
name = "net_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
@@ -832,12 +832,12 @@ dependencies = [
[[package]]
name = "offscreen_gl_context"
version = "0.0.1"
-source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#5d126b050569545204ddb5b9101be64850ebfe5a"
+source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#e79da8f61ad468087beb546bca4d7267b77edd9f"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -1014,8 +1014,8 @@ dependencies = [
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"html5ever 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1049,7 +1049,7 @@ name = "script_traits"
version = "0.0.1"
dependencies = [
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -1164,8 +1164,8 @@ dependencies = [
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"matches 0.1.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1250,7 +1250,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
diff --git a/ports/cef/Cargo.toml b/ports/cef/Cargo.toml
index b6673b73f3e..2c3ce8bc4a6 100644
--- a/ports/cef/Cargo.toml
+++ b/ports/cef/Cargo.toml
@@ -12,6 +12,7 @@ crate-type = ["dylib"]
log = "*"
url = "*"
libc = "*"
+euclid = "0.1"
gleam = "0.1"
[dependencies.servo]
@@ -53,9 +54,6 @@ path = "../../components/devtools"
[dependencies.azure]
git = "https://github.com/servo/rust-azure"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.js]
git = "https://github.com/servo/rust-mozjs"
diff --git a/ports/cef/browser_host.rs b/ports/cef/browser_host.rs
index dd026ae01bb..aeb7c4a9e85 100644
--- a/ports/cef/browser_host.rs
+++ b/ports/cef/browser_host.rs
@@ -11,8 +11,8 @@ use browser::{self, ServoCefBrowserExtensions};
use wrappers::CefWrap;
use compositing::windowing::{WindowEvent, MouseWindowEvent};
-use geom::point::Point2D;
-use geom::size::Size2D;
+use euclid::point::Point2D;
+use euclid::size::Size2D;
use libc::{c_double, c_int};
use msg::constellation_msg::{self, KeyModifiers, KeyState};
use script_traits::MouseButton;
diff --git a/ports/cef/lib.rs b/ports/cef/lib.rs
index 59e018100c3..4cb5abfa4ff 100644
--- a/ports/cef/lib.rs
+++ b/ports/cef/lib.rs
@@ -25,7 +25,7 @@ extern crate servo;
extern crate compositing;
extern crate azure;
-extern crate geom;
+extern crate euclid;
extern crate gfx;
extern crate gleam;
extern crate glutin_app;
diff --git a/ports/cef/window.rs b/ports/cef/window.rs
index b50d94fa145..0d404268ada 100644
--- a/ports/cef/window.rs
+++ b/ports/cef/window.rs
@@ -17,8 +17,8 @@ use wrappers::CefWrap;
use compositing::compositor_task::{self, CompositorProxy, CompositorReceiver};
use compositing::windowing::{WindowEvent, WindowMethods};
-use geom::scale_factor::ScaleFactor;
-use geom::size::{Size2D, TypedSize2D};
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
use gleam::gl;
use layers::geometry::DevicePixel;
use layers::platform::surface::NativeGraphicsMetadata;
diff --git a/ports/glutin/Cargo.toml b/ports/glutin/Cargo.toml
index 2ac08773f85..c5972db9526 100644
--- a/ports/glutin/Cargo.toml
+++ b/ports/glutin/Cargo.toml
@@ -17,6 +17,7 @@ bitflags = "*"
libc = "*"
url = "*"
gleam = "0.1"
+euclid = "0.1"
[dependencies.compositing]
path = "../../components/compositing"
@@ -24,9 +25,6 @@ path = "../../components/compositing"
[dependencies.script_traits]
path = "../../components/script_traits"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
diff --git a/ports/glutin/lib.rs b/ports/glutin/lib.rs
index f7942caf94a..727500e6418 100644
--- a/ports/glutin/lib.rs
+++ b/ports/glutin/lib.rs
@@ -9,7 +9,7 @@
#[macro_use] extern crate bitflags;
#[cfg(target_os="macos")] extern crate cgl;
extern crate compositing;
-extern crate geom;
+extern crate euclid;
extern crate gleam;
extern crate glutin;
extern crate layers;
@@ -24,7 +24,7 @@ extern crate url;
#[cfg(target_os="linux")] extern crate x11;
use compositing::windowing::WindowEvent;
-use geom::scale_factor::ScaleFactor;
+use euclid::scale_factor::ScaleFactor;
use std::rc::Rc;
use window::Window;
use util::opts;
diff --git a/ports/glutin/window.rs b/ports/glutin/window.rs
index 86c9835d15c..83121be8217 100644
--- a/ports/glutin/window.rs
+++ b/ports/glutin/window.rs
@@ -6,8 +6,8 @@
use compositing::compositor_task::{self, CompositorProxy, CompositorReceiver};
use compositing::windowing::{WindowEvent, WindowMethods};
-use geom::scale_factor::ScaleFactor;
-use geom::size::{Size2D, TypedSize2D};
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
use gleam::gl;
use glutin;
use layers::geometry::DevicePixel;
@@ -26,7 +26,7 @@ use NestedEventLoopListener;
#[cfg(feature = "window")]
use compositing::windowing::{MouseWindowEvent, WindowNavigateMsg};
#[cfg(feature = "window")]
-use geom::point::Point2D;
+use euclid::point::Point2D;
#[cfg(feature = "window")]
use glutin::{Api, ElementState, Event, GlRequest, MouseButton, VirtualKeyCode};
#[cfg(feature = "window")]
diff --git a/ports/gonk/Cargo.lock b/ports/gonk/Cargo.lock
index b09a5403705..4cbb247be77 100644
--- a/ports/gonk/Cargo.lock
+++ b/ports/gonk/Cargo.lock
@@ -7,7 +7,7 @@ dependencies = [
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
"env_logger 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"errno 0.1.2 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"gleam 0.0.1 (git+https://github.com/servo/gleam)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -28,15 +28,15 @@ dependencies = [
[[package]]
name = "azure"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-azure#0e864697513c9e31bbe2213957d5713fd6139e69"
+source = "git+https://github.com/servo/rust-azure#d4ae702d7525a560d15e08238c7b7b75c093209d"
dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
"freetype-sys 2.4.11 (git+https://github.com/servo/libfreetype2)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"skia 0.0.20130412 (git+https://github.com/servo/skia)",
"x11 1.1.1 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -64,7 +64,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"canvas_traits 0.0.1",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -80,7 +80,7 @@ version = "0.0.1"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx_traits 0.0.1",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"offscreen_gl_context 0.0.1 (git+https://github.com/ecoal95/rust-offscreen-rendering-context)",
@@ -121,7 +121,7 @@ dependencies = [
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -306,6 +306,17 @@ dependencies = [
]
[[package]]
+name = "euclid"
+version = "0.1.0"
+source = "registry+https://github.com/rust-lang/crates.io-index"
+dependencies = [
+ "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
+ "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
+ "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
+]
+
+[[package]]
name = "expat-sys"
version = "2.1.0"
source = "git+https://github.com/servo/libexpat#83f914d964af73ba38aa413455a2009cc6cb2618"
@@ -361,17 +372,6 @@ version = "0.3.8"
source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
-name = "geom"
-version = "0.1.0"
-source = "git+https://github.com/servo/rust-geom#16b91afc0b9b532f2fb56879069bc381f2143df1"
-dependencies = [
- "log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "num 0.1.25 (registry+https://github.com/rust-lang/crates.io-index)",
- "rand 0.3.8 (registry+https://github.com/rust-lang/crates.io-index)",
- "rustc-serialize 0.3.15 (registry+https://github.com/rust-lang/crates.io-index)",
-]
-
-[[package]]
name = "gfx"
version = "0.0.1"
dependencies = [
@@ -381,10 +381,10 @@ dependencies = [
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-graphics 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-text 0.1.0 (git+https://github.com/servo/core-text-rs)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fontconfig 0.1.0 (git+https://github.com/servo/rust-fontconfig)",
"freetype 0.1.0 (git+https://github.com/servo/rust-freetype)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx_traits 0.0.1",
"harfbuzz 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -525,11 +525,11 @@ dependencies = [
[[package]]
name = "io-surface"
version = "0.1.0"
-source = "git+https://github.com/servo/io-surface-rs#7f8d819c7c2cef9ba6e057478bc13f01fe5e5a96"
+source = "git+https://github.com/servo/io-surface-rs#401cf1d0a90290aa832b622061257d2ce985f69b"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
]
@@ -562,13 +562,13 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
[[package]]
name = "layers"
version = "0.1.0"
-source = "git+https://github.com/servo/rust-layers#76d90799f152a78c35c90d9d7a9311a68e98937a"
+source = "git+https://github.com/servo/rust-layers#65001b9e18631172a457c31c04be990639c02c35"
dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
@@ -590,8 +590,8 @@ dependencies = [
"clock_ticks 0.0.6 (git+https://github.com/tomaka/clock_ticks)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"gfx_traits 0.0.1",
"layout_traits 0.0.1",
@@ -618,7 +618,7 @@ dependencies = [
name = "layout_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gfx 0.0.1",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -693,7 +693,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"io-surface 0.1.0 (git+https://github.com/servo/io-surface-rs)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -710,8 +710,8 @@ version = "0.0.1"
dependencies = [
"cookie 0.1.21 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"flate2 0.2.7 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"net_traits 0.0.1",
@@ -730,7 +730,7 @@ dependencies = [
name = "net_traits"
version = "0.0.1"
dependencies = [
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
@@ -760,12 +760,12 @@ dependencies = [
[[package]]
name = "offscreen_gl_context"
version = "0.0.1"
-source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#5d126b050569545204ddb5b9101be64850ebfe5a"
+source = "git+https://github.com/ecoal95/rust-offscreen-rendering-context#e79da8f61ad468087beb546bca4d7267b77edd9f"
dependencies = [
"cgl 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"core-foundation 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"egl 0.1.0 (git+https://github.com/servo/rust-egl)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"gleam 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"glx 0.0.1 (git+https://github.com/servo/rust-glx)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
@@ -933,8 +933,8 @@ dependencies = [
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"devtools_traits 0.0.1",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"gfx 0.0.1",
"html5ever 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"hyper 0.5.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -968,7 +968,7 @@ name = "script_traits"
version = "0.0.1"
dependencies = [
"devtools_traits 0.0.1",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
"msg 0.0.1",
"net_traits 0.0.1",
@@ -1073,8 +1073,8 @@ dependencies = [
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"encoding 0.2.32 (registry+https://github.com/rust-lang/crates.io-index)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"fnv 1.0.0 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"log 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
"matches 0.1.2 (registry+https://github.com/rust-lang/crates.io-index)",
@@ -1150,7 +1150,7 @@ dependencies = [
"azure 0.1.0 (git+https://github.com/servo/rust-azure)",
"bitflags 0.2.1 (registry+https://github.com/rust-lang/crates.io-index)",
"cssparser 0.3.1 (registry+https://github.com/rust-lang/crates.io-index)",
- "geom 0.1.0 (git+https://github.com/servo/rust-geom)",
+ "euclid 0.1.0 (registry+https://github.com/rust-lang/crates.io-index)",
"layers 0.1.0 (git+https://github.com/servo/rust-layers)",
"lazy_static 0.1.11 (registry+https://github.com/rust-lang/crates.io-index)",
"libc 0.1.8 (registry+https://github.com/rust-lang/crates.io-index)",
diff --git a/ports/gonk/Cargo.toml b/ports/gonk/Cargo.toml
index 9076e215dd0..880c17b22be 100644
--- a/ports/gonk/Cargo.toml
+++ b/ports/gonk/Cargo.toml
@@ -8,9 +8,6 @@ build = "build.rs"
[dependencies.compositing]
path = "../../components/compositing"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.layers]
git = "https://github.com/servo/rust-layers"
@@ -60,3 +57,4 @@ url = "0.2.16"
time = "0.1.17"
errno = "*"
libc = "*"
+euclid = "0.1"
diff --git a/ports/gonk/src/input.rs b/ports/gonk/src/input.rs
index 42e9d6df41f..a8d3bfb7169 100644
--- a/ports/gonk/src/input.rs
+++ b/ports/gonk/src/input.rs
@@ -14,7 +14,7 @@ use std::thread;
use std::sync::mpsc::Sender;
use std::io::Read;
-use geom::point::Point2D;
+use euclid::point::Point2D;
use errno::errno;
use libc::c_int;
diff --git a/ports/gonk/src/main.rs b/ports/gonk/src/main.rs
index 7e13bb71e5e..19c1a0fb256 100644
--- a/ports/gonk/src/main.rs
+++ b/ports/gonk/src/main.rs
@@ -31,7 +31,7 @@ extern crate errno;
extern crate compositing;
extern crate script_traits;
-extern crate geom;
+extern crate euclid;
extern crate libc;
extern crate msg;
extern crate gleam;
diff --git a/ports/gonk/src/window.rs b/ports/gonk/src/window.rs
index 40221996afe..cca9e9e4627 100644
--- a/ports/gonk/src/window.rs
+++ b/ports/gonk/src/window.rs
@@ -6,8 +6,8 @@
use compositing::compositor_task::{self, CompositorProxy, CompositorReceiver};
use compositing::windowing::{WindowEvent, WindowMethods};
-use geom::scale_factor::ScaleFactor;
-use geom::size::{Size2D, TypedSize2D};
+use euclid::scale_factor::ScaleFactor;
+use euclid::size::{Size2D, TypedSize2D};
use layers::geometry::DevicePixel;
use layers::platform::surface::NativeGraphicsMetadata;
use libc::c_int;
diff --git a/tests/unit/style/Cargo.toml b/tests/unit/style/Cargo.toml
index dc6078eb9e9..c6dc27e52be 100644
--- a/tests/unit/style/Cargo.toml
+++ b/tests/unit/style/Cargo.toml
@@ -14,9 +14,6 @@ path = "../../../components/style"
[dependencies.util]
path = "../../../components/util"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies.selectors]
git = "https://github.com/servo/rust-selectors"
@@ -25,3 +22,4 @@ url = "*"
cssparser = "0.3.1"
string_cache = "0.1"
string_cache_plugin = "0.1"
+euclid = "0.1"
diff --git a/tests/unit/style/lib.rs b/tests/unit/style/lib.rs
index a90707b522c..7b6c48814bd 100644
--- a/tests/unit/style/lib.rs
+++ b/tests/unit/style/lib.rs
@@ -6,7 +6,7 @@
#![plugin(string_cache_plugin)]
extern crate cssparser;
-extern crate geom;
+extern crate euclid;
extern crate selectors;
extern crate string_cache;
extern crate style;
diff --git a/tests/unit/style/media_queries.rs b/tests/unit/style/media_queries.rs
index ff996a9e717..2f1dd734a7f 100644
--- a/tests/unit/style/media_queries.rs
+++ b/tests/unit/style/media_queries.rs
@@ -2,7 +2,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-use geom::size::Size2D;
+use euclid::size::Size2D;
use style::stylesheets::{Stylesheet, CSSRuleIteratorExt};
use style::stylesheets::Origin;
use style::media_queries::*;
diff --git a/tests/unit/style/viewport.rs b/tests/unit/style/viewport.rs
index 970a91fc5c5..1e7cfe4cd93 100644
--- a/tests/unit/style/viewport.rs
+++ b/tests/unit/style/viewport.rs
@@ -3,8 +3,8 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
use cssparser::Parser;
-use geom::size::Size2D;
-use geom::scale_factor::ScaleFactor;
+use euclid::size::Size2D;
+use euclid::scale_factor::ScaleFactor;
use style::media_queries::{Device, MediaType};
use style::parser::ParserContext;
use style::stylesheets::{Origin, Stylesheet, CSSRuleIteratorExt};
diff --git a/tests/unit/util/Cargo.toml b/tests/unit/util/Cargo.toml
index 21edb79c613..7982ddd5285 100644
--- a/tests/unit/util/Cargo.toml
+++ b/tests/unit/util/Cargo.toml
@@ -15,9 +15,7 @@ path = "../../../components/util"
[dependencies.plugins]
path = "../../../components/plugins"
-[dependencies.geom]
-git = "https://github.com/servo/rust-geom"
-
[dependencies]
libc = "*"
+euclid = "0.1"
diff --git a/tests/unit/util/lib.rs b/tests/unit/util/lib.rs
index badcbd40e7a..198858b8d4e 100644
--- a/tests/unit/util/lib.rs
+++ b/tests/unit/util/lib.rs
@@ -6,7 +6,7 @@
#![plugin(plugins)]
extern crate util;
extern crate libc;
-extern crate geom;
+extern crate euclid;
#[cfg(test)] mod cache;
#[cfg(test)] mod logical_geometry;
diff --git a/tests/unit/util/logical_geometry.rs b/tests/unit/util/logical_geometry.rs
index c0df54c3b3f..bb36ff162ff 100644
--- a/tests/unit/util/logical_geometry.rs
+++ b/tests/unit/util/logical_geometry.rs
@@ -2,7 +2,7 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-use geom::{Size2D, Point2D, SideOffsets2D, Rect};
+use euclid::{Size2D, Point2D, SideOffsets2D, Rect};
use util::logical_geometry::{WritingMode, LogicalSize, LogicalPoint, LogicalMargin, LogicalRect,
FLAG_RTL, FLAG_VERTICAL, FLAG_VERTICAL_LR, FLAG_SIDEWAYS_LEFT};
diff --git a/components/util/geometry.rs b/components/util/geometry.rs
index 25fb284fcb3..5f493f19660 100644
--- a/components/util/geometry.rs
+++ b/components/util/geometry.rs
@@ -2,11 +2,11 @@
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
-use geom::length::Length;
-use geom::point::Point2D;
-use geom::rect::Rect;
-use geom::size::Size2D;
-use geom::num::Zero;
+use euclid::length::Length;
+use euclid::point::Point2D;
+use euclid::rect::Rect;
+use euclid::size::Size2D;
+use euclid::num::Zero;
use std::default::Default;
use std::i32;
@@ -15,7 +15,7 @@ use std::ops::{Add, Sub, Neg, Mul, Div, Rem};
use rustc_serialize::{Encoder, Encodable};
// Units for use with geom::length and geom::scale_factor.
/// A normalized "pixel" at the default resolution for the display.
///
@@ -15,7 +15,7 @@ use std::ops::{Add, Sub, Neg, Mul, Div, Rem};
use rustc_serialize::{Encoder, Encodable};
-// Units for use with geom::length and geom::scale_factor.
+// Units for use with euclid::length and euclid::scale_factor.
/// A normalized "pixel" at the default resolution for the display.
///